@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,11 +11,10 @@
 """ The interface for a simple 'About' dialog. """
 
 
-from traits.api import HasTraits, Instance, List, Str
-
+from traits.api import HasTraits, List, Str
 
 from pyface.i_dialog import IDialog
-from pyface.image_resource import ImageResource
+from pyface.ui_traits import Image
 
 
 class IAboutDialog(IDialog):
@@ -30,10 +29,23 @@ class IAboutDialog(IDialog):
     copyrights = List(Str)
 
     #: The image displayed in the dialog.
-    image = Instance(ImageResource, ImageResource("about"))
+    image = Image()
 
 
 class MAboutDialog(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IAboutDialog interface.
     """
+
+    #: Additional strings to be added to the dialog.
+    additions = List(Str)
+
+    #: Additional copyright strings to be added above the standard ones.
+    copyrights = List(Str)
+
+    #: The image displayed in the dialog.
+    image = Image()
+
+    def _image_default(self):
+        from .image_resource import ImageResource
+        return ImageResource('about')
