@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,7 +11,7 @@
 
 import unittest
 
-from traits.api import Any, HasTraits, Str
+from traits.api import HasTraits, Str
 
 from ..splash_screen_log_handler import SplashScreenLogHandler
 
