@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,6 +15,7 @@ import unittest
 from traits.api import Instance
 from traits.testing.api import UnittestTools
 
+from pyface.testing.widget_mixin import WidgetMixin
 from ..application_window import ApplicationWindow
 from ..toolkit import toolkit_object
 from ..widget import Widget
@@ -24,6 +25,7 @@ no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 is_qt = (toolkit_object.toolkit in {"qt4", "qt"})
 is_linux = (sys.platform == "linux")
+is_mac = (sys.platform == "darwin")
 
 
 class ConcreteWidget(Widget):
@@ -41,7 +43,7 @@ class ConcreteWidget(Widget):
             control = QtGui.QWidget(parent)
             control.setEnabled(self.enabled)
             control.setVisible(self.visible)
-            control.setFocusPolicy(Qt.StrongFocus)
+            control.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
         else:
             control = None
         return control
@@ -320,9 +322,9 @@ class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
 
         self.assertFalse(self.widget.control.isEnabled())
 
-    @unittest.skipIf(
-        is_linux,
-        "Linux keyboard focus is False unless window is active",
+    @unittest.skipUnless(
+        is_mac,
+        "Broken on Linux and Windows",
     )
     def test_focus(self):
         with self.event_loop():
@@ -334,3 +336,9 @@ class TestConcreteWidget(unittest.TestCase, GuiTestAssistant):
             self.widget.focus()
 
         self.assertTrue(self.widget.has_focus())
+
+
+class TestWidgetCommon(WidgetMixin, unittest.TestCase):
+
+    def _create_widget(self):
+        return ConcreteWidget(parent=self.parent.control, tooltip='Dummy')
