@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -28,7 +28,8 @@ from traits.api import Instance, List, observe, provides, Str
 
 
 from pyface.i_application_window import IApplicationWindow, MApplicationWindow
-from pyface.image_resource import ImageResource
+from pyface.ui_traits import Image
+from .image_resource import ImageResource
 from .window import Window
 
 
@@ -41,7 +42,7 @@ class ApplicationWindow(MApplicationWindow, Window):
     # 'IApplicationWindow' interface ---------------------------------------
 
     #: The icon to display in the application window title bar.
-    icon = Instance(ImageResource)
+    icon = Image()
 
     #: The menu bar manager for the window.
     menu_bar_manager = Instance(MenuBarManager)
@@ -68,7 +69,7 @@ class ApplicationWindow(MApplicationWindow, Window):
         panel = QtGui.QWidget(parent)
 
         palette = QtGui.QPalette(panel.palette())
-        palette.setColor(QtGui.QPalette.Window, QtGui.QColor("blue"))
+        palette.setColor(QtGui.QPalette.ColorRole.Window, QtGui.QColor("blue"))
         panel.setPalette(palette)
         panel.setAutoFillBackground(True)
 
@@ -129,7 +130,7 @@ class ApplicationWindow(MApplicationWindow, Window):
     # ------------------------------------------------------------------------
 
     def _create(self):
-        super(ApplicationWindow, self)._create()
+        super()._create()
 
         contents = self._create_contents(self.control)
         self.control.setCentralWidget(contents)
@@ -137,7 +138,7 @@ class ApplicationWindow(MApplicationWindow, Window):
         self._create_trim_widgets(self.control)
 
     def _create_control(self, parent):
-        control = super(ApplicationWindow, self)._create_control(parent)
+        control = super()._create_control(parent)
         control.setObjectName("ApplicationWindow")
 
         control.setAnimated(False)
@@ -167,14 +168,16 @@ class ApplicationWindow(MApplicationWindow, Window):
     # assignment. For this reason, it is unnecessary to delete the old controls
     # in the following two handlers.
 
-    def _menu_bar_manager_changed(self):
+    @observe("menu_bar_manager")
+    def _menu_bar_manager_updated(self, event):
         if self.control is not None:
             self._create_menu_bar(self.control)
 
-    def _status_bar_manager_changed(self, old, new):
+    @observe("status_bar_manager")
+    def _status_bar_manager_updated(self, event):
         if self.control is not None:
-            if old is not None:
-                old.destroy_status_bar()
+            if event.old is not None:
+                event.old.destroy()
             self._create_status_bar(self.control)
 
     @observe("tool_bar_manager, tool_bar_managers.items")
@@ -189,5 +192,6 @@ class ApplicationWindow(MApplicationWindow, Window):
             # Add the new toolbars.
             self._create_tool_bar(self.control)
 
-    def _icon_changed(self):
+    @observe("icon")
+    def _icon_updated(self, event):
         self._set_window_icon()
