@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -22,7 +22,7 @@ from traits.testing.unittest_tools import (
     _TraitsChangeCollector as TraitsChangeCollector,
 )
 
-from .testing import find_qt_widget, print_qt_widget_tree
+from .testing import find_qt_widget
 from .event_loop_helper import EventLoopHelper, ConditionTimeoutError
 
 
@@ -40,7 +40,7 @@ class GuiTestAssistant(UnittestTools):
             qt_app=self.qt_app, gui=self.gui
         )
         try:
-            import traitsui.api
+            import traitsui.api  # noqa: F401
         except ImportError:
             self.traitsui_raise_patch = None
         else:
@@ -75,7 +75,6 @@ class GuiTestAssistant(UnittestTools):
             with self.event_loop_with_timeout(repeat=5):
                 self.gui.invoke_later(self.qt_app.closeAllWindows)
 
-        self.qt_app.flush()
         self.pyface_raise_patch.stop()
         if self.traitsui_raise_patch is not None:
             self.traitsui_raise_patch.stop()
@@ -133,6 +132,20 @@ class GuiTestAssistant(UnittestTools):
         This should not be used to wait for widget deletion. Use
         delete_widget() instead.
 
+        Notes
+        -----
+
+        This runs the real Qt event loop, polling the condition every 50 ms and
+        returning as soon as the condition becomes true. If the condition does
+        not become true within the given timeout, a ConditionTimeoutError is
+        raised.
+
+        Because the state of the condition is only polled every 50 ms, it
+        may fail to detect transient states that appear and disappear within
+        a 50 ms window.  Code should ensure that any state that is being
+        tested by the condition cannot revert to a False value once it becomes
+        True.
+
         Parameters
         ----------
         condition : callable
@@ -155,9 +168,19 @@ class GuiTestAssistant(UnittestTools):
         Assert that the given condition becomes true if we run the GUI
         event loop for long enough.
 
+        Notes
+        -----
+
         This assertion runs the real Qt event loop, polling the condition
-        and returning as soon as the condition becomes true. If the condition
-        does not become true within the given timeout, the assertion fails.
+        every 50 ms and returning as soon as the condition becomes true. If
+        the condition does not become true within the given timeout, the
+        assertion fails.
+
+        Because the state of the condition is only polled every 50 ms, it
+        may fail to detect transient states that appear and disappear within
+        a 50 ms window.  Tests should ensure that any state that is being
+        tested by the condition cannot revert to a False value once it becomes
+        True.
 
         Parameters
         ----------
