@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -40,7 +40,7 @@ class Editor(MEditor):
         control = QtGui.QWidget(parent)
 
         pal = control.palette()
-        pal.setColour(QtGui.QPalette.Window, QtCore.Qt.yellow)
+        pal.setColour(QtGui.QPalette.ColorRole.Window, QtCore.Qt.GlobalColor.yellow)
         control.setPalette(pal)
 
         control.setAutoFillBackground(True)
