@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -63,7 +63,7 @@ class SingleChoiceDialog(MSingleChoiceDialog, Dialog):
             self.choice = self.choices[self.control.GetSelection()]
 
         # Let the window close as normal.
-        super(SingleChoiceDialog, self).close()
+        super().close()
 
     # ------------------------------------------------------------------------
     # Protected 'IWidget' interface.
